@@ -31,6 +31,7 @@ from typing import (
 from xotl.tools.objects import lazy, setdefaultattr
 
 from .ranges import Range
+from .tracing import get_module_sentry_spanner
 from .types import Domain, TEq, TOrd
 
 
@@ -92,7 +93,8 @@ class EquivalenceSet(Generic[TEq]):
         return self.values > other.values
 
     def __and__(
-        self, other: "EquivalenceSet"
+        self,
+        other: "EquivalenceSet",
     ) -> "EquivalenceSet":  # pragma: no cover
         if isinstance(other, IntervalSet):
             return self.to_interval_set() & other
@@ -101,7 +103,8 @@ class EquivalenceSet(Generic[TEq]):
         return EquivalenceSet(self.values & other.values)
 
     def diff(
-        self, other: "EquivalenceSet"
+        self,
+        other: "EquivalenceSet",
     ) -> "EquivalenceSet":  # pragma: no cover
         if isinstance(other, IntervalSet):
             return self.to_interval_set().diff(other)
@@ -112,7 +115,8 @@ class EquivalenceSet(Generic[TEq]):
     __sub__ = difference = diff
 
     def __or__(
-        self, other: "EquivalenceSet"
+        self,
+        other: "EquivalenceSet",
     ) -> "EquivalenceSet":  # pragma: no cover
         if isinstance(other, IntervalSet):
             return self.to_interval_set() | other
@@ -121,7 +125,8 @@ class EquivalenceSet(Generic[TEq]):
         return EquivalenceSet(self.values | other.values)
 
     def union(
-        self, *others: "EquivalenceSet"
+        self,
+        *others: "EquivalenceSet",
     ) -> "EquivalenceSet":  # pragma: no cover
         from functools import reduce
         from operator import or_
@@ -176,7 +181,8 @@ class IntervalSet(Generic[TOrd]):
 
     @classmethod
     def _from_ordered_disjoint(
-        cls, bases: Iterable[Range[TOrd]]
+        cls,
+        bases: Iterable[Range[TOrd]],
     ) -> "IntervalSet[TOrd]":
         result = cls([])
         result.ranges = tuple(bases)
@@ -184,7 +190,8 @@ class IntervalSet(Generic[TOrd]):
 
     @classmethod
     def _extract_ranges(
-        cls, other: Union["IntervalSet[TOrd]", Range[TOrd]]
+        cls,
+        other: Union["IntervalSet[TOrd]", Range[TOrd]],
     ) -> Tuple[Range[TOrd], ...]:
         if isinstance(other, EquivalenceSet):
             return other.to_interval_set().ranges
@@ -196,7 +203,8 @@ class IntervalSet(Generic[TOrd]):
 
     @classmethod
     def _extract_all_ranges(
-        cls, *args: Iterable[Union["IntervalSet[TOrd]", Range[TOrd]]]
+        cls,
+        *args: Iterable[Union["IntervalSet[TOrd]", Range[TOrd]]],
     ) -> Tuple[Range[TOrd], ...]:
         return tuple(
             base
@@ -281,13 +289,14 @@ class IntervalSet(Generic[TOrd]):
         return IntervalSet(bases)
 
     def union(self, *others: "IntervalSet[TOrd]") -> "IntervalSet[TOrd]":
-        all_ranges = self._extract_all_ranges(self.ranges, others)
-        if all_ranges:
-            base, *bases = all_ranges
-            new_bases = base.join(*bases)
-        else:
-            new_bases = ()
-        return IntervalSet(new_bases)
+        with sentry_span("IntervalSet.union"):
+            all_ranges = self._extract_all_ranges(self.ranges, others)
+            if all_ranges:
+                base, *bases = all_ranges
+                new_bases = base.join(*bases)
+            else:
+                new_bases = ()
+            return IntervalSet(new_bases)
 
     __or__ = join = union
 
@@ -299,85 +308,87 @@ class IntervalSet(Generic[TOrd]):
         #  theirs   |---------------|  |-|          |-------|
         #
         # Our __init__ ensures this.
-        if isinstance(other, EquivalenceSet):
-            other = other.to_interval_set()
-        ours = deque(self.ranges)
-        theirs = deque(other.ranges)
-        results = []
-        while ours and theirs:
-            top: Range = ours.popleft()
-            bottom: Range = theirs.popleft()
-            assert top and bottom
-            if top == bottom:
-                # Nothing to produce here, both sub-ranges are consumed.
-                pass
-            elif top & bottom:
-                # There are four possible cases here (five if we count top ==
-                # bottom, but we ruled that out):
-                #
-                # case:       a     !     b    !    c   !    d
-                # ~~~~~~~~~~~~~~~~~~+~~~~~~~~~~+~~~~~~~~+~~~~~~~~~
-                # top      |------| !   |----| ! |---|  !   |--|
-                # bottom     |--|   ! |---|    !   |---|! |------|
-                #
-                # The case 'a' will produce a range to "left" that cannot
-                # intercept with any other range; so we can put it the
-                # results.  The second range may intercept with another of
-                # theirs so we put it in the front of ours.  But this case,
-                # has two sub-cases:
-                #
-                #                a.1               a.2
-                #   top        |-----|   and    |-----|
-                #   bottom     |---|               |--|
-                #
-                # In the first sub-case we cannot push the diff to the result.
-                # In the second we have nothing to push to ours.  But those
-                # can be treated the same as the cases 'b' and 'c'.
-                diff = top.diff(bottom)
-                if diff:
-                    if (
-                        len(diff) > 1
-                    ):  # ->                                   case 'a'.
-                        left, right = diff
-                        results.append(left)
-                        ours.appendleft(right)
-                    else:
-                        assert len(diff) == 1
+        with sentry_span("IntervalSet.diff"):
+            if isinstance(other, EquivalenceSet):
+                other = other.to_interval_set()
+            ours = deque(self.ranges)
+            theirs = deque(other.ranges)
+            results = []
+            while ours and theirs:
+                top: Range = ours.popleft()
+                bottom: Range = theirs.popleft()
+                assert top and bottom
+                if top == bottom:
+                    # Nothing to produce here, both sub-ranges are consumed.
+                    pass
+                elif top & bottom:
+                    # There are four possible cases here (five if we count top
+                    # == bottom, but we ruled that out):
+                    #
+                    # case:       a     !     b    !    c   !    d
+                    # ~~~~~~~~~~~~~~~~~~+~~~~~~~~~~+~~~~~~~~+~~~~~~~~~
+                    # top      |------| !   |----| ! |---|  !   |--|
+                    # bottom     |--|   ! |---|    !   |---|! |------|
+                    #
+                    # The case 'a' will produce a range to "left" that cannot
+                    # intercept with any other range; so we can put it the
+                    # results.  The second range may intercept with another of
+                    # theirs so we put it in the front of ours.  But this
+                    # case, has two sub-cases:
+                    #
+                    #                a.1               a.2
+                    #   top        |-----|   and    |-----|
+                    #   bottom     |---|               |--|
+                    #
+                    # In the first sub-case we cannot push the diff to the
+                    # result.  In the second we have nothing to push to ours.
+                    # But those can be treated the same as the cases 'b' and
+                    # 'c'.
+                    diff = top.diff(bottom)
+                    if diff:
                         if (
-                            bottom.lowerbound <= top.lowerbound
-                        ):  # ->         cases 'b' or a.1
-                            ours.appendleft(diff[0])
-                        elif (
-                            top.upperbound <= bottom.upperbound
-                        ):  # ->       cases 'c' or a.2
-                            results.append(diff[0])
-                            # We need to reintroduce bottom to theirs, because
-                            # it can overlap with the next top of 'ours'.
-                            theirs.appendleft(bottom)
+                            len(diff) > 1
+                        ):  # ->                                   case 'a'.
+                            left, right = diff
+                            results.append(left)
+                            ours.appendleft(right)
                         else:
-                            assert False
-                else:  # ->                                                   case 'd'
-                    # We need to reintroduce bottom to theirs, because it can
-                    # overlap with the next top of 'ours'.
-                    theirs.appendleft(bottom)
-            else:
-                # There are two cases here:
-                #
-                #                 'a'               'b'
-                #   top             |-----|   and    |-----|
-                #   bottom     |---|                        |--|
-                #
-                if bottom.upperbound <= top.lowerbound:
-                    ours.appendleft(top)
-                elif top.upperbound <= bottom.lowerbound:
-                    theirs.appendleft(bottom)
-                else:  # pragma: no cover
-                    assert False
+                            assert len(diff) == 1
+                            if (
+                                bottom.lowerbound <= top.lowerbound
+                            ):  # ->                        cases 'b' or a.1
+                                ours.appendleft(diff[0])
+                            elif (
+                                top.upperbound <= bottom.upperbound
+                            ):  # ->                        cases 'c' or a.2
+                                results.append(diff[0])
+                                # We need to reintroduce bottom to theirs, because
+                                # it can overlap with the next top of 'ours'.
+                                theirs.appendleft(bottom)
+                            else:
+                                assert False
+                    else:  # ->                                  case 'd'
+                        # We need to reintroduce bottom to theirs, because it
+                        # can overlap with the next top of 'ours'.
+                        theirs.appendleft(bottom)
+                else:
+                    # There are two cases here:
+                    #
+                    #                 'a'               'b'
+                    #   top             |-----|   and    |-----|
+                    #   bottom     |---|                        |--|
+                    #
+                    if bottom.upperbound <= top.lowerbound:
+                        ours.appendleft(top)
+                    elif top.upperbound <= bottom.lowerbound:
+                        theirs.appendleft(bottom)
+                    else:  # pragma: no cover
+                        assert False
 
-        if ours:
-            assert not theirs
-            results.extend(ours)
-        return IntervalSet._from_ordered_disjoint(results)
+            if ours:
+                assert not theirs
+                results.extend(ours)
+            return IntervalSet._from_ordered_disjoint(results)
 
     __sub__ = difference = diff
 
@@ -418,6 +429,9 @@ def iter_domain_endpoints(domains: Sequence[Domain[TOrd]]) -> Iterator[TOrd]:
             assert False, f"Unknown type of domain {domain.__class__}"
 
 
+sentry_span = get_module_sentry_spanner(__name__)
+
+
 if TYPE_CHECKING:  # pragma: no cover
     from datetime import datetime, timedelta
 
