@@ -28,16 +28,28 @@ from ...ranges import Excluded, Included, Range
 # the following generators so that generated ranges have a sensible and
 # predictable behavior.
 numbers = st.floats(
-    allow_infinity=False, allow_nan=False, min_value=-10000.0, max_value=10000.0
+    allow_infinity=False,
+    allow_nan=False,
+    min_value=-10000.0,
+    max_value=10000.0,
 )
 nonnegative_numbers = st.floats(
-    allow_infinity=False, allow_nan=False, min_value=0, max_value=10000.0
+    allow_infinity=False,
+    allow_nan=False,
+    min_value=0,
+    max_value=10000.0,
 )
 negative_numbers = st.floats(
-    allow_infinity=False, allow_nan=False, min_value=-10000.0, max_value=-1
+    allow_infinity=False,
+    allow_nan=False,
+    min_value=-10000.0,
+    max_value=-1,
 )
 positive_numbers = st.floats(
-    allow_infinity=False, allow_nan=False, min_value=1, max_value=10000.0
+    allow_infinity=False,
+    allow_nan=False,
+    min_value=1,
+    max_value=10000.0,
 )
 
 
