@@ -8,10 +8,9 @@
 #
 from collections import deque
 from dataclasses import dataclass
-
 from typing import Iterator
-from typing_extensions import Protocol
 
+from typing_extensions import Protocol
 from xotl.tools.string import cut_prefix, cut_suffix
 
 
@@ -32,7 +31,10 @@ class NodeRef:
         return f"<&{node}>"
 
 
-def pruned_prefix_walk(node: Node, prune_entirely: bool = False) -> Iterator[NodeRef]:
+def pruned_prefix_walk(
+    node: Node,
+    prune_entirely: bool = False,
+) -> Iterator[NodeRef]:
     r"""Produced a pruned prefix walk of a Directed Acyclic Graph.
 
     By default, pruned means that the same subgraph is never yielded more than
@@ -77,6 +79,7 @@ def pruned_prefix_walk(node: Node, prune_entirely: bool = False) -> Iterator[Nod
 
     And finally, let's walk the graph:
 
+        >>> from xotless.walk import pruned_prefix_walk
         >>> list(pruned_prefix_walk(a))
         [<&a>, <&b>, <&d>, <&c>, <&b>, <&f>, <&d>, <&e>, <&f>]
 
@@ -99,6 +102,10 @@ def pruned_prefix_walk(node: Node, prune_entirely: bool = False) -> Iterator[Nod
         yield NodeRef(current)
         if current not in memory:
             memory.add(current)
-            children = [n for n in iter(current) if not prune_entirely or n not in memory]
+            children = [
+                n
+                for n in iter(current)
+                if not prune_entirely or n not in memory
+            ]
             children.reverse()
             nodes.extendleft(children)
